==> stonesthrow-0.1.tar.gz: stonesthrow-0.1/setup.py <==
from distutils.core import setup
setup(
  name = 'stonesthrow',         # How you named your package folder (MyLib)
  packages = ['stonesthrow'],   # Chose the same as "name"
  version = '0.1',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'A rudimentary peer-to-peer API for sending data, easily.',   # Give a short description about your library
  author = 'Cliff Syner',                   # Type in your name
  url = 'https://github.com/c4syner/Stonesthrow',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/c4syner/Stonesthrow/archive/v0.1-alpha.tar.gz',    # I explain this later on
  keywords = ['API', 'DATA', 'NETWORKING'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'requests',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)

==> stonesthrow-0.3.tar.gz: stonesthrow-0.3/setup.py <==
from distutils.core import setup
setup(
  name = 'stonesthrow',         # How you named your package folder (MyLib)
  packages = ['stonesthrow'],   # Chose the same as "name"
  version = '0.3',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'A rudimentary peer-to-peer API for sending data, easily.',   # Give a short description about your library
  author = 'Cliff Syner',                   # Type in your name
  url = 'https://github.com/c4syner/Stonesthrow',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/c4syner/Stonesthrow/archive/v3.tar.gz',    # I explain this later on
  keywords = ['API', 'DATA', 'NETWORKING'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'requests',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)
